@@ -436,9 +436,9 @@ terminal_app_new_window (TerminalWindow *window,
   win_attr->display = g_strdup (gdk_display_get_name (gdk_screen_get_display (screen)));
   tab_attr = win_attr->tabs->data;
   tab_attr->directory = g_strdup (working_directory);
-  if (window->font)
-    win_attr->font = g_strdup (window->font);
-  win_attr->zoom = window->zoom;
+  if (terminal_window_get_font (window))
+    win_attr->font = g_strdup (terminal_window_get_font (window));
+  win_attr->zoom = terminal_window_get_zoom_level (window);
 
   /* check if we should try to inherit the parent geometry */
   g_object_get (G_OBJECT (app->preferences), "misc-inherit-geometry", &inherit_geometry, NULL);
@@ -740,11 +740,19 @@ terminal_app_open_window (TerminalApp        *app,
           gtk_window_set_screen (GTK_WINDOW (window), screen);
         }
     }
-  else if (attr->reuse_last_window
-           && app->windows != NULL)
+  else if (attr->reuse_last_window && app->windows != NULL)
     {
-      /* open the tabs in an existing window */
+      /* open tabs in the existing window */
       window = app->windows->data;
+      /* try to find active window (bug #13891) */
+      for (lp = app->windows; lp != NULL; lp = lp->next)
+        {
+          if (gtk_window_has_toplevel_focus (GTK_WINDOW (lp->data)))
+            {
+              window = lp->data;
+              break;
+            }
+        }
       reuse_window = TRUE;
     }
   else
@@ -788,11 +796,8 @@ terminal_app_open_window (TerminalApp        *app,
   if (!reuse_window)
     {
       if (attr->font)
-        {
-          g_free (TERMINAL_WINDOW (window)->font);
-          TERMINAL_WINDOW (window)->font = g_strdup (attr->font);
-        }
-      TERMINAL_WINDOW (window)->zoom = attr->zoom;
+        terminal_window_set_font (TERMINAL_WINDOW (window), attr->font);
+      terminal_window_set_zoom_level (TERMINAL_WINDOW (window), attr->zoom);
     }
 
   if (!attr->drop_down)
@@ -819,39 +824,7 @@ terminal_app_open_window (TerminalApp        *app,
           if (mask & YValue)
             y = new_y;
         }
-
-        if ((mask & XValue) || (mask & YValue))
-          {
-            screen = gtk_window_get_screen (GTK_WINDOW (window));
-  #if GTK_CHECK_VERSION (3, 22, 0)
-            gdk_window_get_geometry (gdk_screen_get_root_window (screen), NULL, NULL,
-                                     &screen_width, &screen_height);
-  #else
-            screen_width = gdk_screen_get_width (screen);
-            screen_height = gdk_screen_get_height (screen);
-  #endif
-            gtk_window_get_default_size (GTK_WINDOW (window), &window_width, &window_height);
-            if (mask & XNegative)
-              {
-                x = screen_width - window_width + x;
-                gravity = GDK_GRAVITY_NORTH_EAST;
-              }
-            if (mask & YNegative)
-              {
-                y = screen_height - window_height + y;
-                gravity = (mask & XNegative) ? GDK_GRAVITY_SOUTH_EAST : GDK_GRAVITY_SOUTH_WEST;
-              }
-            gtk_window_set_gravity (GTK_WINDOW (window), gravity);
-            gtk_window_move (GTK_WINDOW (window), x, y);
-          }
-      else if (!(mask & WidthValue) && !(mask & XValue))
-#else
-      if (!gtk_window_parse_geometry (GTK_WINDOW (window), geometry))
 #endif
-        g_printerr (_("Invalid geometry string \"%s\"\n"), geometry);
-
-      /* cleanup */
-      g_free (geometry);
     }
 
   /* add the tabs */
@@ -864,6 +837,44 @@ terminal_app_open_window (TerminalApp        *app,
       terminal_screen_launch_child (terminal);
     }
 
+  if (!attr->drop_down)
+    {
+      /* move the window to desired position */
+#ifdef GDK_WINDOWING_X11
+      if ((mask & XValue) || (mask & YValue))
+        {
+          screen = gtk_window_get_screen (GTK_WINDOW (window));
+  #if GTK_CHECK_VERSION (3, 22, 0)
+          gdk_window_get_geometry (gdk_screen_get_root_window (screen), NULL, NULL,
+                                   &screen_width, &screen_height);
+  #else
+          screen_width = gdk_screen_get_width (screen);
+          screen_height = gdk_screen_get_height (screen);
+  #endif
+          gtk_window_get_size (GTK_WINDOW (window), &window_width, &window_height);
+          if (mask & XNegative)
+            {
+              x = screen_width - window_width + x;
+              gravity = GDK_GRAVITY_NORTH_EAST;
+            }
+          if (mask & YNegative)
+            {
+              y = screen_height - window_height + y;
+              gravity = (mask & XNegative) ? GDK_GRAVITY_SOUTH_EAST : GDK_GRAVITY_SOUTH_WEST;
+            }
+          gtk_window_set_gravity (GTK_WINDOW (window), gravity);
+          gtk_window_move (GTK_WINDOW (window), x, y);
+        }
+      else if (!(mask & WidthValue) && !(mask & XValue))
+#else
+      if (!gtk_window_parse_geometry (GTK_WINDOW (window), geometry))
+#endif
+        g_printerr (_("Invalid geometry string \"%s\"\n"), geometry);
+
+      /* cleanup */
+      g_free (geometry);
+    }
+
   /* show the window */
   if (attr->drop_down)
     terminal_window_dropdown_toggle (TERMINAL_WINDOW_DROPDOWN (window), attr->startup_id, reuse_window);
