@@ -20,6 +20,8 @@ GType terminal_ambiguous_width_binding_get_type (void);
 #define TERMINAL_TYPE_AMBIGUOUS_WIDTH_BINDING (terminal_ambiguous_width_binding_get_type())
 GType terminal_cursor_shape_get_type (void);
 #define TERMINAL_TYPE_CURSOR_SHAPE (terminal_cursor_shape_get_type())
+GType terminal_text_blink_mode_get_type (void);
+#define TERMINAL_TYPE_TEXT_BLINK_MODE (terminal_text_blink_mode_get_type())
 G_END_DECLS
 
 #endif /* !TERMINAL_ENUM_TYPES_H */
