@@ -21,6 +21,7 @@
 #define TERMINAL_OPTIONS_H
 
 #include <glib.h>
+#include <terminal/terminal-preferences.h>
 
 G_BEGIN_DECLS
 
@@ -53,10 +54,12 @@ typedef enum
 
 typedef struct
 {
-  gchar    **command;
-  gchar     *directory;
-  gchar     *title;
-  guint      hold : 1;
+  gchar       **command;
+  gchar        *directory;
+  gchar        *title;
+  gchar        *initial_title;
+  TerminalTitle dynamic_title_mode;
+  guint         hold : 1;
 } TerminalTabAttr;
 
 typedef struct
