@@ -286,6 +286,7 @@ terminal_screen_init (TerminalScreen *screen)
   screen->working_directory = g_get_current_dir ();
   screen->dynamic_title_mode = TERMINAL_TITLE_DEFAULT;
   screen->session_id = ++screen_last_session_id;
+  screen->pid = -1;
 
   screen->terminal = g_object_new (TERMINAL_TYPE_WIDGET, NULL);
   g_signal_connect (G_OBJECT (screen->terminal), "child-exited",
@@ -1302,16 +1303,19 @@ terminal_screen_vte_child_exited (VteTerminal    *terminal,
                                   gint            status,
                                   TerminalScreen *screen)
 {
-  GtkWidget *window, *dialog, *label, *content_area;
+  GtkWidget *window, *dialog, *content_area, *label, *checkbox;
   gchar     *message;
   gint       response;
+  gboolean   show_relaunch_dialog;
 
   terminal_return_if_fail (VTE_IS_TERMINAL (terminal));
   terminal_return_if_fail (TERMINAL_IS_SCREEN (screen));
 
+  g_object_get (G_OBJECT (screen->preferences), "misc-show-relaunch-dialog", &show_relaunch_dialog, NULL);
+
   if (G_LIKELY (!screen->hold))
     gtk_widget_destroy (GTK_WIDGET (screen));
-  else
+  else if (show_relaunch_dialog)
     {
       /* create "Relaunch" dialog */
       window = gtk_widget_get_toplevel (GTK_WIDGET (screen));
@@ -1323,25 +1327,31 @@ terminal_screen_vte_child_exited (VteTerminal    *terminal,
                                             NULL);
       gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_YES);
 
+      content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+      gtk_box_set_spacing (GTK_BOX (content_area), 6);
+
       if (WIFEXITED (status))
         message = g_strdup_printf (_("The child process exited normally with status %d."), WEXITSTATUS (status));
       else if (WIFSIGNALED (status))
         message = g_strdup_printf (_("The child process was aborted by signal %d."), WTERMSIG (status));
       else
-        message = g_strdup_printf (_("The child process was aborted."));
+        message = g_strdup (_("The child process was aborted."));
 
       label = gtk_label_new (message);
       g_free (message);
-
-      content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
       gtk_container_add (GTK_CONTAINER (content_area), label);
 
+      checkbox = gtk_check_button_new_with_mnemonic (_("Do _not ask me again"));
+      gtk_container_add (GTK_CONTAINER (content_area), checkbox);
+
       gtk_widget_show_all (dialog);
       response = gtk_dialog_run (GTK_DIALOG (dialog));
 
-      /* relaunch the process */
+      /* relaunch the process or remember to not show it anymore */
       if (response == GTK_RESPONSE_YES)
         terminal_screen_launch_child (screen);
+      else if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (checkbox)))
+        g_object_set (G_OBJECT (screen->preferences), "misc-show-relaunch-dialog", FALSE, NULL);
 
       gtk_widget_destroy (dialog);
     }
@@ -1692,11 +1702,8 @@ terminal_screen_spawn_async_cb (VteTerminal *terminal,
   screen->pid = pid;
 
   if (error)
-    {
-      xfce_dialog_show_error (GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (screen))),
-                              error, _("Failed to execute child"));
-      g_error_free (error);
-    }
+    xfce_dialog_show_error (GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (screen))),
+                            error, _("Failed to execute child"));
 }
 #endif
 
@@ -2638,10 +2645,7 @@ terminal_screen_update_font (TerminalScreen *screen)
   if (G_LIKELY (font_name != NULL))
     {
       font_desc = pango_font_description_from_string (font_name);
-#if !VTE_CHECK_VERSION (0, 51, 3)
-      /* "bold-is-bright" is used since vte 0.51.3 */
       vte_terminal_set_allow_bold (VTE_TERMINAL (screen->terminal), font_allow_bold);
-#endif
       vte_terminal_set_font (VTE_TERMINAL (screen->terminal), font_desc);
       pango_font_description_free (font_desc);
       g_free (font_name);
@@ -2734,7 +2738,7 @@ terminal_screen_has_foreground_process (TerminalScreen *screen)
   int     fd;
   int     fgpid;
 
-  if (screen == NULL)
+  if (screen == NULL || screen->pid == -1)
     return FALSE;
 
   pty = vte_terminal_get_pty (VTE_TERMINAL (screen->terminal));
