@@ -81,14 +81,14 @@ terminal_util_show_about_dialog (GtkWindow *parent)
                          "documenters", documenters,
                          "copyright", "Copyright \302\251 2003-2008 Benedikt Meurer\n"
                                       "Copyright \302\251 2007-2012 Nick Schermer\n"
-                                      "Copyright \302\251 2016-2017 Igor Zakharov",
+                                      "Copyright \302\251 2016-2018 Igor Zakharov",
                          "license", XFCE_LICENSE_GPL,
                          "logo-icon-name", "utilities-terminal",
                          "program-name", PACKAGE_NAME,
                          "translator-credits", _("translator-credits"),
                          "version", PACKAGE_VERSION,
                          "website", "http://docs.xfce.org/apps/terminal/start",
-                         "website-label", _("Visit Terminal website"),
+                         "website-label", _("Visit Xfce Terminal website"),
                          NULL);
 }
 
@@ -98,9 +98,10 @@ void
 terminal_util_activate_window (GtkWindow *window)
 {
 #ifdef GDK_WINDOWING_X11
-  guint32             timestamp;
-  XClientMessageEvent event;
-  GdkWindow          *gdk_window = gtk_widget_get_window (GTK_WIDGET (window));
+  guint32              timestamp;
+  XClientMessageEvent  event;
+  GdkWindow           *gdk_window = gtk_widget_get_window (GTK_WIDGET (window));
+  GdkDisplay          *display = gdk_window_get_display (gdk_window);
 
   terminal_return_if_fail (GTK_IS_WINDOW (window));
   terminal_return_if_fail (gtk_widget_get_realized (GTK_WIDGET (window)));
@@ -127,15 +128,15 @@ terminal_util_activate_window (GtkWindow *window)
   event.data.l[1] = timestamp;
   event.data.l[2] = event.data.l[3] = event.data.l[4] = 0;
 
-  gdk_error_trap_push ();
+  gdk_x11_display_error_trap_push (display);
 
   XSendEvent (gdk_x11_get_default_xdisplay (),
               gdk_x11_get_default_root_xwindow (), False,
               StructureNotifyMask, (XEvent *) &event);
 
-  gdk_flush ();
+  gdk_display_flush (display);
 
-  if (gdk_error_trap_pop () != 0)
+  if (gdk_x11_display_error_trap_pop (display) != 0)
     g_critical ("Failed to focus window");
 #else
   /* our best guess on non-x11 clients */
