@@ -15,8 +15,8 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __TERMINAL_DIALOGS_H__
-#define __TERMINAL_DIALOGS_H__
+#ifndef TERMINAL_UTIL_H
+#define TERMINAL_UTIL_H
 
 #include <gtk/gtk.h>
 
@@ -28,4 +28,4 @@ void terminal_util_activate_window    (GtkWindow    *window);
 
 G_END_DECLS
 
-#endif /* !__TERMINAL_DIALOGS_H__ */
+#endif /* !TERMINAL_UTIL_H */
