@@ -27,6 +27,9 @@
 #ifdef HAVE_STRING_H
 #include <string.h>
 #endif
+#ifdef HAVE_LIBUTEMPTER
+#include <utempter.h>
+#endif
 
 #include <libxfce4ui/libxfce4ui.h>
 
@@ -193,6 +196,12 @@ terminal_widget_finalize (GObject *object)
 {
   TerminalWidget *widget = TERMINAL_WIDGET (object);
 
+#ifdef HAVE_LIBUTEMPTER
+  VtePty *pty = vte_terminal_get_pty (VTE_TERMINAL (widget));
+  if (VTE_IS_PTY (pty))
+    utempter_remove_record (vte_pty_get_fd (pty));
+#endif
+
   /* disconnect the misc-highlight-urls watch */
   g_signal_handlers_disconnect_by_func (G_OBJECT (widget->preferences), G_CALLBACK (terminal_widget_update_highlight_urls), widget);
 
@@ -609,7 +618,7 @@ terminal_widget_key_press_event (GtkWidget    *widget,
   /* determine current settings */
   g_object_get (G_OBJECT (TERMINAL_WIDGET (widget)->preferences),
                 "shortcuts-no-menukey", &shortcuts_no_menukey,
-                "misc-shift-arrows-scroll", &shift_arrows_scroll,
+                "misc-use-shift-arrows-to-scroll", &shift_arrows_scroll,
                 NULL);
 
   /* popup context menu if "Menu" or "<Shift>F10" is pressed */
@@ -648,7 +657,7 @@ terminal_widget_open_uri (TerminalWidget *widget,
 {
   GtkWindow *window = GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (widget)));
   GError    *error = NULL;
-  gchar     *uri, *escaped;
+  gchar     *uri;
   guint      i;
 
   for (i = 0; i < G_N_ELEMENTS (regex_patterns); i++)
@@ -669,8 +678,8 @@ terminal_widget_open_uri (TerminalWidget *widget,
             break;
 
           case PATTERN_TYPE_EMAIL:
-            uri = g_str_has_prefix (wlink, MAILTO "//")
-                ? g_strdup (wlink) : g_strconcat (MAILTO "//", wlink, NULL);
+            uri = strncmp (wlink, MAILTO, strlen (MAILTO)) == 0
+                ? g_strdup (wlink) : g_strconcat (MAILTO, wlink, NULL);
             break;
 
           default:
@@ -686,11 +695,8 @@ terminal_widget_open_uri (TerminalWidget *widget,
                          uri, gtk_get_current_event_time (), &error))
 #endif
         {
-          /* escape ampersand symbols, etc. */
-          escaped = g_markup_escape_text (uri, -1);
           /* tell the user that we were unable to open the responsible application */
-          xfce_dialog_show_error (window, error, _("Failed to open the URL '%s'"), escaped);
-          g_free (escaped);
+          xfce_dialog_show_error (window, error, _("Failed to open the URL '%s'"), uri);
           g_error_free (error);
         }
 
